@@ -5,7 +5,7 @@ port.name <- args[1]
 print(port.name)
 
 # Initial MPI.
-library(pbdMPI, quiet = TRUE)
+library(pbdMPI, quietly = TRUE)
 init()
 server.comm <- .SPMD.CT$newcomm
 
