@@ -1,6 +1,6 @@
 ### SHELL> mpiexec -np 2 Rscript --vanilla [...].r
 
-library(pbdMPI, quiet = TRUE)
+library(pbdMPI, quietly = TRUE)
 init()
 .comm.size <- comm.size()
 .comm.rank <- comm.rank()
