@@ -42,14 +42,10 @@ SEXP spmd_comm_size(SEXP R_comm);
 SEXP spmd_comm_rank(SEXP R_comm);
 SEXP spmd_comm_dup(SEXP R_comm, SEXP R_newcomm);
 SEXP spmd_comm_set_errhandler(SEXP R_comm);
-
-// For MPI-2 only
-SEXP spmd_comm_spawn(SEXP R_worker, SEXP R_workerargv, SEXP R_nworker,
-		SEXP R_info, SEXP R_rank_source, SEXP R_intercomm);
-
 SEXP spmd_comm_get_parent(SEXP R_comm);
 SEXP spmd_is_master();
 SEXP spmd_comm_abort(SEXP R_comm, SEXP R_errorcode);
+SEXP spmd_comm_split(SEXP R_comm, SEXP R_color, SEXP R_key, SEXP R_newcomm);
 SEXP spmd_comm_disconnect(SEXP R_comm);
 SEXP spmd_comm_connect(SEXP R_port_name, SEXP R_info, SEXP R_root, SEXP R_comm,
                 SEXP R_newcomm);
@@ -61,9 +57,15 @@ SEXP spmd_serv_publish(SEXP R_serv_name, SEXP R_info, SEXP R_port_name);
 SEXP spmd_serv_unpublish(SEXP R_serv_name, SEXP R_info, SEXP R_port_name);
 SEXP spmd_serv_lookup(SEXP R_serv_name, SEXP R_info);
 SEXP spmd_intercomm_merge(SEXP R_intercomm, SEXP R_high, SEXP R_comm);
-
+SEXP spmd_intercomm_create(SEXP R_local_comm, SEXP R_local_leader,
+		SEXP R_peer_comm, SEXP R_remote_leader, SEXP R_tag,
+		SEXP R_newintercomm);
 SEXP spmd_comm_c2f(SEXP R_comm);
 
+/* In file "spmd_communicator_spawn.c". */
+SEXP spmd_comm_spawn(SEXP R_worker, SEXP R_workerargv, SEXP R_nworker,
+		SEXP R_info, SEXP R_rank_source, SEXP R_intercomm);
+
 /* In file "spmd_allgather.c". */
 SEXP spmd_allgather_integer(SEXP R_send_data, SEXP R_recv_data,
 		SEXP R_comm);
